@@ -7,15 +7,30 @@ import boto3
 
 
 class Deployer(object):
-    def __init__(self, dir, docker=False, environment="prod"):
+    def __init__(self, name, dir, docker=False, environment="prod"):
         self.dir = dir
         script_dir = os.path.dirname(os.path.realpath(__file__))
         self.jinja = Environment(loader=FileSystemLoader(script_dir))
-        self.project_name = "legoon"
+        self.project_name = name
         self.environment = environment
         self.docker = docker
 
-    def deploy(self):
+    def _get_env_vars(self):
+        # Getting environment variables.
+        env_vars = []
+        for name, value in os.environ.items():
+            if name[0:4] == "BLD_":
+                env_vars.append(
+                    {
+                        "name": name[4:],
+                        "alpha_name": name[4:].replace("_", ""),
+                        "value": value,
+                        "type": "String",
+                    }
+                )
+        return env_vars
+
+    def _build_template(self):
         # Running files to create subclasses.
         # TODO: Change these from hardcoded to dynamic.
         exec(open("function.py").read())
@@ -36,19 +51,20 @@ class Deployer(object):
         for api in api_classes:
             inst = api()
             methods = inst.get_methods()
-            for method in methods:
-                api_functions.append(
-                    {"name": api.__name__, "endpoint": api.endpoint, "method": method}
-                )
+            api_functions.append(
+                {"name": api.__name__, "endpoint": api.endpoint, "methods": methods}
+            )
 
         # Creating SAM template.
         template = self.jinja.get_template("sam.j2")
 
+        env_vars = self._get_env_vars()
+
         rendered = template.render(
             description="Test",
             functions=lambda_functions,
             api_functions=api_functions,
-            environment_variables=[],
+            environment_variables=env_vars,
             dynamo_tables=[],
             subdomain=self.project_name,
         )
@@ -56,6 +72,9 @@ class Deployer(object):
         f.write(rendered)
         f.close()
 
+    def deploy(self):
+        self._build_template()
+
         # Creating S3 bucket for SAM.
         # TODO: Set this to create a random bucket if the name is taken or something.
         s3 = boto3.client("s3")
@@ -77,6 +96,11 @@ class Deployer(object):
             ],
             cwd=self.dir,
         )
+        env_vars = self._get_env_vars()
+        overrides = [
+            f"ParameterKey={x['alpha_name']},ParameterValue={x['value']}"
+            for x in env_vars
+        ]
         subprocess.run(
             [
                 "sam",
@@ -89,9 +113,32 @@ class Deployer(object):
                 f"{self.project_name}-{self.environment}",
                 "--parameter-overrides",
                 f"ENVIRONMENT={self.environment}",
+                ",".join(overrides),
             ],
             cwd=self.dir,
             check=True,
         )
 
         print("Deployed successfully.")
+
+    def start_api(self):
+        self._build_template()
+        subprocess.run(["sam", "build", "--use-container"], cwd=self.dir, check=True)
+        env_vars = self._get_env_vars()
+        overrides = [f"{x['alpha_name']}={x['value']}" for x in env_vars]
+        subprocess.run(
+            [
+                "sam",
+                "local",
+                "start-api",
+                "-d 5858",
+                "--parameter-overrides",
+                ",".join(overrides),
+            ],
+            cwd=self.dir,
+            check=True,
+        )
+
+    def invoke(self, function):
+        self._build_template()
+        subprocess.run(["sam", "local", "invoke", function], cwd=self.dir, check=True)
